You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by ha...@apache.org on 2009/03/06 09:20:11 UTC

svn commit: r750806 [3/7] - in /camel/trunk: camel-core/src/main/java/org/apache/camel/ camel-core/src/main/java/org/apache/camel/builder/ camel-core/src/main/java/org/apache/camel/impl/ camel-core/src/main/java/org/apache/camel/management/ camel-core/...

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorDefinition.java Fri Mar  6 08:20:00 2009
@@ -47,9 +47,9 @@
 import org.apache.camel.builder.ExpressionClause;
 import org.apache.camel.builder.NoErrorHandlerBuilder;
 import org.apache.camel.builder.ProcessorBuilder;
-import org.apache.camel.model.dataformat.DataFormatType;
+import org.apache.camel.model.dataformat.DataFormatDefinition;
 import org.apache.camel.model.language.ConstantExpression;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.model.language.LanguageExpression;
 import org.apache.camel.processor.DelegateProcessor;
 import org.apache.camel.processor.Enricher;
@@ -73,18 +73,18 @@
  * @version $Revision$
  */
 @XmlAccessorType(XmlAccessType.PROPERTY)
-public abstract class ProcessorType<Type extends ProcessorType> extends OptionalIdentifiedType<Type> implements Block {
-    private static final transient Log LOG = LogFactory.getLog(ProcessorType.class);
+public abstract class ProcessorDefinition<Type extends ProcessorDefinition> extends OptionalIdentifiedType<Type> implements Block {
+    private static final transient Log LOG = LogFactory.getLog(ProcessorDefinition.class);
     private ErrorHandlerBuilder errorHandlerBuilder;
     private Boolean inheritErrorHandlerFlag;
     private NodeFactory nodeFactory;
     private LinkedList<Block> blocks = new LinkedList<Block>();
-    private ProcessorType parent;
-    private List<InterceptorType> interceptors = new ArrayList<InterceptorType>();
+    private ProcessorDefinition parent;
+    private List<InterceptorDefinition> interceptors = new ArrayList<InterceptorDefinition>();
     private String errorHandlerRef;
 
     // else to use an optional attribute in JAXB2
-    public abstract List<ProcessorType> getOutputs();
+    public abstract List<ProcessorDefinition> getOutputs();
 
 
     public Processor createProcessor(RouteContext routeContext) throws Exception {
@@ -92,7 +92,7 @@
     }
 
     public Processor createOutputsProcessor(RouteContext routeContext) throws Exception {
-        Collection<ProcessorType> outputs = getOutputs();
+        Collection<ProcessorDefinition> outputs = getOutputs();
         return createOutputsProcessor(routeContext, outputs);
     }
 
@@ -123,7 +123,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type to(String uri) {
-        addOutput(new ToType(uri));
+        addOutput(new ToDefinition(uri));
         return (Type) this;
     }   
     
@@ -136,7 +136,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type to(Endpoint endpoint) {
-        addOutput(new ToType(endpoint));
+        addOutput(new ToDefinition(endpoint));
         return (Type) this;
     }
     
@@ -149,7 +149,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type to(ExchangePattern pattern, String uri) {
-        addOutput(new ToType(uri, pattern));
+        addOutput(new ToDefinition(uri, pattern));
         return (Type) this;
     }   
     
@@ -163,7 +163,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type to(ExchangePattern pattern, Endpoint endpoint) {
-        addOutput(new ToType(endpoint, pattern));
+        addOutput(new ToDefinition(endpoint, pattern));
         return (Type) this;
     }
 
@@ -176,7 +176,7 @@
     @SuppressWarnings("unchecked")
     public Type to(String... uris) {
         for (String uri : uris) {
-            addOutput(new ToType(uri));
+            addOutput(new ToDefinition(uri));
         }
         return (Type) this;
     }
@@ -191,7 +191,7 @@
     @SuppressWarnings("unchecked")
     public Type to(Endpoint... endpoints) {
         for (Endpoint endpoint : endpoints) {
-            addOutput(new ToType(endpoint));
+            addOutput(new ToDefinition(endpoint));
         }
         return (Type) this;
     }
@@ -205,7 +205,7 @@
     @SuppressWarnings("unchecked")
     public Type to(Iterable<Endpoint> endpoints) {
         for (Endpoint endpoint : endpoints) {
-            addOutput(new ToType(endpoint));
+            addOutput(new ToDefinition(endpoint));
         }
         return (Type) this;
     }
@@ -221,7 +221,7 @@
     @SuppressWarnings("unchecked")
     public Type to(ExchangePattern pattern, String... uris) {
         for (String uri : uris) {
-            addOutput(new ToType(uri, pattern));
+            addOutput(new ToDefinition(uri, pattern));
         }
         return (Type) this;
     }
@@ -236,7 +236,7 @@
     @SuppressWarnings("unchecked")
     public Type to(ExchangePattern pattern, Endpoint... endpoints) {
         for (Endpoint endpoint : endpoints) {
-            addOutput(new ToType(endpoint, pattern));
+            addOutput(new ToDefinition(endpoint, pattern));
         }
         return (Type) this;
     }
@@ -251,7 +251,7 @@
     @SuppressWarnings("unchecked")
     public Type to(ExchangePattern pattern, Iterable<Endpoint> endpoints) {
         for (Endpoint endpoint : endpoints) {
-            addOutput(new ToType(endpoint, pattern));
+            addOutput(new ToDefinition(endpoint, pattern));
         }
         return (Type) this;
     }
@@ -266,7 +266,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type setExchangePattern(ExchangePattern exchangePattern) {
-        addOutput(new SetExchangePatternType(exchangePattern));
+        addOutput(new SetExchangePatternDefinition(exchangePattern));
         return (Type) this;
     }
 
@@ -426,8 +426,8 @@
      *
      * @return the builder
      */
-    public MulticastType multicast() {
-        MulticastType answer = new MulticastType();
+    public MulticastDefinition multicast() {
+        MulticastDefinition answer = new MulticastDefinition();
         addOutput(answer);
         return answer;
     }
@@ -443,8 +443,8 @@
      * @param parallelProcessing if is <tt>true</tt> camel will fork thread to call the endpoint producer
      * @return the builder
      */
-    public MulticastType multicast(AggregationStrategy aggregationStrategy, boolean parallelProcessing) {
-        MulticastType answer = new MulticastType();
+    public MulticastDefinition multicast(AggregationStrategy aggregationStrategy, boolean parallelProcessing) {
+        MulticastDefinition answer = new MulticastDefinition();
         addOutput(answer);
         answer.setAggregationStrategy(aggregationStrategy);
         answer.setParallelProcessing(parallelProcessing);
@@ -461,8 +461,8 @@
      *          every part
      * @return the builder
      */
-    public MulticastType multicast(AggregationStrategy aggregationStrategy) {
-        MulticastType answer = new MulticastType();
+    public MulticastDefinition multicast(AggregationStrategy aggregationStrategy) {
+        MulticastDefinition answer = new MulticastDefinition();
         addOutput(answer);
         answer.setAggregationStrategy(aggregationStrategy);
         return answer;
@@ -513,7 +513,7 @@
      * @return the builder
      */
     @SuppressWarnings("unchecked")
-    public ProcessorType<? extends ProcessorType> end() {
+    public ProcessorDefinition<? extends ProcessorDefinition> end() {
         if (blocks.isEmpty()) {
             if (parent == null) {
                 throw new IllegalArgumentException("Root node with no active block");
@@ -532,8 +532,8 @@
      * @return a ThreadType builder that can be used to further configure the
      *         the thread pool.
      */
-    public ThreadType thread(int coreSize) {
-        ThreadType answer = new ThreadType(coreSize);
+    public ThreadDefinition thread(int coreSize) {
+        ThreadDefinition answer = new ThreadDefinition(coreSize);
         addOutput(answer);
         return answer;
     }
@@ -546,8 +546,8 @@
      * @return a ThreadType builder that can be used to further configure the
      *         the thread pool.
      */
-    public ProcessorType<Type> thread(Executor executor) {
-        ThreadType answer = new ThreadType(executor);
+    public ProcessorDefinition<Type> thread(Executor executor) {
+        ThreadDefinition answer = new ThreadDefinition(executor);
         addOutput(answer);
         return this;
     }
@@ -559,8 +559,8 @@
      *      
      * @return the builder
      */
-    public IdempotentConsumerType idempotentConsumer() {
-        IdempotentConsumerType answer = new IdempotentConsumerType();
+    public IdempotentConsumerDefinition idempotentConsumer() {
+        IdempotentConsumerDefinition answer = new IdempotentConsumerDefinition();
         addOutput(answer);
         return answer;
     }
@@ -574,9 +574,9 @@
      * @param idempotentRepository  the repository to use for duplicate chedck
      * @return the builder
      */
-    public IdempotentConsumerType idempotentConsumer(Expression messageIdExpression,
+    public IdempotentConsumerDefinition idempotentConsumer(Expression messageIdExpression,
             IdempotentRepository idempotentRepository) {
-        IdempotentConsumerType answer = new IdempotentConsumerType(messageIdExpression, idempotentRepository);
+        IdempotentConsumerDefinition answer = new IdempotentConsumerDefinition(messageIdExpression, idempotentRepository);
         addOutput(answer);
         return answer;
     }
@@ -589,8 +589,8 @@
      * @param idempotentRepository the repository to use for duplicate chedck
      * @return the builder used to create the expression
      */
-    public ExpressionClause<IdempotentConsumerType> idempotentConsumer(IdempotentRepository idempotentRepository) {
-        IdempotentConsumerType answer = new IdempotentConsumerType();
+    public ExpressionClause<IdempotentConsumerDefinition> idempotentConsumer(IdempotentRepository idempotentRepository) {
+        IdempotentConsumerDefinition answer = new IdempotentConsumerDefinition();
         answer.setMessageIdRepository(idempotentRepository);
         addOutput(answer);
         return ExpressionClause.createAndSetExpression(answer);
@@ -603,8 +603,8 @@
      *
      * @return the clause used to create the filter expression
      */
-    public ExpressionClause<FilterType> filter() {
-        FilterType filter = new FilterType();
+    public ExpressionClause<FilterDefinition> filter() {
+        FilterDefinition filter = new FilterDefinition();
         addOutput(filter);
         return ExpressionClause.createAndSetExpression(filter);
     }
@@ -617,8 +617,8 @@
      * @param predicate  predicate to use
      * @return the builder 
      */
-    public FilterType filter(Predicate predicate) {
-        FilterType filter = new FilterType(predicate);
+    public FilterDefinition filter(Predicate predicate) {
+        FilterDefinition filter = new FilterDefinition(predicate);
         addOutput(filter);
         return filter;
     }
@@ -631,8 +631,8 @@
      * @param expression  the predicate expression to use
      * @return the builder
      */
-    public FilterType filter(ExpressionType expression) {
-        FilterType filter = getNodeFactory().createFilter();
+    public FilterDefinition filter(ExpressionDefinition expression) {
+        FilterDefinition filter = getNodeFactory().createFilter();
         filter.setExpression(expression);
         addOutput(filter);
         return filter;
@@ -647,7 +647,7 @@
      * @param expression   the expression
      * @return the builder
      */
-    public FilterType filter(String language, String expression) {
+    public FilterDefinition filter(String language, String expression) {
         return filter(new LanguageExpression(language, expression));
     }
 
@@ -657,8 +657,8 @@
      *
      * @return  the builder
      */
-    public LoadBalanceType loadBalance() {
-        LoadBalanceType answer = new LoadBalanceType();
+    public LoadBalanceDefinition loadBalance() {
+        LoadBalanceDefinition answer = new LoadBalanceDefinition();
         addOutput(answer);
         return answer;
     }
@@ -670,8 +670,8 @@
      *
      * @return the builder for a choice expression
      */
-    public ChoiceType choice() {
-        ChoiceType answer = new ChoiceType();
+    public ChoiceDefinition choice() {
+        ChoiceDefinition answer = new ChoiceDefinition();
         addOutput(answer);
         return answer;
     }
@@ -681,8 +681,8 @@
      *
      * @return the builder for a tryBlock expression
      */
-    public TryType tryBlock() {
-        TryType answer = new TryType();
+    public TryDefinition tryBlock() {
+        TryDefinition answer = new TryDefinition();
         addOutput(answer);
         return answer;
     }
@@ -696,7 +696,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type recipientList(Expression recipients) {
-        RecipientListType answer = new RecipientListType(recipients);
+        RecipientListDefinition answer = new RecipientListDefinition(recipients);
         addOutput(answer);
         return (Type) this;
     }
@@ -707,10 +707,10 @@
      *
      * @return the expression clause to configure the expression to decide the destinations
      */
-    public ExpressionClause<ProcessorType<Type>> recipientList() {
-        RecipientListType answer = new RecipientListType();
+    public ExpressionClause<ProcessorDefinition<Type>> recipientList() {
+        RecipientListDefinition answer = new RecipientListDefinition();
         addOutput(answer);
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>(this);
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>(this);
         answer.setExpression(clause);
         return clause;
     }
@@ -728,7 +728,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type routingSlip(String header, String uriDelimiter) {
-        RoutingSlipType answer = new RoutingSlipType(header, uriDelimiter);
+        RoutingSlipDefinition answer = new RoutingSlipDefinition(header, uriDelimiter);
         addOutput(answer);
         return (Type) this;
     }
@@ -738,7 +738,7 @@
      * Creates a routing slip allowing you to route a message consecutively through a series of processing
      * steps where the sequence of steps is not known at design time and can vary for each message.
      * <p>
-     * The list of URIs will be split based on the default delimiter {@link RoutingSlipType#DEFAULT_DELIMITER}
+     * The list of URIs will be split based on the default delimiter {@link RoutingSlipDefinition#DEFAULT_DELIMITER}
      *
      * @param header  is the header that the {@link org.apache.camel.processor.RoutingSlip RoutingSlip}
      *                class will look in for the list of URIs to route the message to.
@@ -746,7 +746,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type routingSlip(String header) {
-        RoutingSlipType answer = new RoutingSlipType(header);
+        RoutingSlipDefinition answer = new RoutingSlipDefinition(header);
         addOutput(answer);
         return (Type) this;
     }
@@ -760,8 +760,8 @@
      *
      * @return the expression clause builder for the expression on which to split
      */
-    public ExpressionClause<SplitterType> split() {
-        SplitterType answer = new SplitterType();
+    public ExpressionClause<SplitterDefinition> split() {
+        SplitterDefinition answer = new SplitterDefinition();
         addOutput(answer);
         return ExpressionClause.createAndSetExpression(answer);
     }
@@ -776,8 +776,8 @@
      * @param expression  the expression on which to split the message
      * @return the builder
      */
-    public SplitterType split(Expression expression) {
-        SplitterType answer = new SplitterType(expression);
+    public SplitterDefinition split(Expression expression) {
+        SplitterDefinition answer = new SplitterDefinition(expression);
         addOutput(answer);
         return answer;
     }
@@ -792,8 +792,8 @@
      * @param aggregationStrategy  the strategy used to aggregate responses for every part
      * @return the builder
      */
-    public SplitterType split(Expression expression, AggregationStrategy aggregationStrategy) {
-        SplitterType answer = new SplitterType(expression);
+    public SplitterDefinition split(Expression expression, AggregationStrategy aggregationStrategy) {
+        SplitterDefinition answer = new SplitterDefinition(expression);
         addOutput(answer);
         answer.setAggregationStrategy(aggregationStrategy);
         return answer;
@@ -805,10 +805,10 @@
      *
      * @return the expression clause for the expressions on which to compare messages in order
      */
-    public ExpressionClause<ResequencerType> resequence() {
-        ResequencerType answer = new ResequencerType();
+    public ExpressionClause<ResequencerDefinition> resequence() {
+        ResequencerDefinition answer = new ResequencerDefinition();
         addOutput(answer);
-        ExpressionClause<ResequencerType> clause = new ExpressionClause<ResequencerType>(answer);
+        ExpressionClause<ResequencerDefinition> clause = new ExpressionClause<ResequencerDefinition>(answer);
         answer.expression(clause);
         return clause;
     }
@@ -820,7 +820,7 @@
      * @param expression the expression on which to compare messages in order
      * @return the builder
      */
-    public ResequencerType resequence(Expression expression) {
+    public ResequencerDefinition resequence(Expression expression) {
         return resequence(Collections.<Expression>singletonList(expression));
     }
 
@@ -831,8 +831,8 @@
      * @param expressions the list of expressions on which to compare messages in order
      * @return the builder
      */
-    public ResequencerType resequence(List<Expression> expressions) {
-        ResequencerType answer = new ResequencerType(expressions);
+    public ResequencerDefinition resequence(List<Expression> expressions) {
+        ResequencerDefinition answer = new ResequencerDefinition(expressions);
         addOutput(answer);
         return answer;
     }
@@ -844,7 +844,7 @@
      * @param expressions the list of expressions on which to compare messages in order
      * @return the builder
      */
-    public ResequencerType resequencer(Expression... expressions) {
+    public ResequencerDefinition resequencer(Expression... expressions) {
         List<Expression> list = new ArrayList<Expression>();
         list.addAll(Arrays.asList(expressions));
         return resequence(list);
@@ -856,8 +856,8 @@
      *
      * @return the expression clause to be used as builder to configure the correlation expression
      */
-    public ExpressionClause<AggregatorType> aggregate() {
-        AggregatorType answer = new AggregatorType();
+    public ExpressionClause<AggregatorDefinition> aggregate() {
+        AggregatorDefinition answer = new AggregatorDefinition();
         addOutput(answer);
         return answer.createAndSetExpression();
     }
@@ -869,8 +869,8 @@
      * @param aggregationStrategy the strategy used for the aggregation
      * @return the expression clause to be used as builder to configure the correlation expression
      */
-    public ExpressionClause<AggregatorType> aggregate(AggregationStrategy aggregationStrategy) {
-        AggregatorType answer = new AggregatorType();
+    public ExpressionClause<AggregatorDefinition> aggregate(AggregationStrategy aggregationStrategy) {
+        AggregatorDefinition answer = new AggregatorDefinition();
         answer.setAggregationStrategy(aggregationStrategy);
         addOutput(answer);
         return answer.createAndSetExpression();
@@ -883,8 +883,8 @@
      * @param aggregationCollection the collection used to perform the aggregation
      * @return the builder
      */
-    public AggregatorType aggregate(AggregationCollection aggregationCollection) {
-        AggregatorType answer = new AggregatorType();
+    public AggregatorDefinition aggregate(AggregationCollection aggregationCollection) {
+        AggregatorDefinition answer = new AggregatorDefinition();
         answer.setAggregationCollection(aggregationCollection);
         addOutput(answer);
         return answer;
@@ -900,8 +900,8 @@
      *                              <code>header("JMSCorrelationID")</code>
      * @return the builder
      */
-    public AggregatorType aggregate(Expression correlationExpression) {
-        AggregatorType answer = new AggregatorType(correlationExpression);
+    public AggregatorDefinition aggregate(Expression correlationExpression) {
+        AggregatorDefinition answer = new AggregatorDefinition(correlationExpression);
         addOutput(answer);
         return answer;
     }
@@ -917,8 +917,8 @@
      * @param aggregationStrategy the strategy used for the aggregation
      * @return the builder
      */
-    public AggregatorType aggregate(Expression correlationExpression, AggregationStrategy aggregationStrategy) {
-        AggregatorType answer = new AggregatorType(correlationExpression, aggregationStrategy);
+    public AggregatorDefinition aggregate(Expression correlationExpression, AggregationStrategy aggregationStrategy) {
+        AggregatorDefinition answer = new AggregatorDefinition(correlationExpression, aggregationStrategy);
         addOutput(answer);
         return answer;
     }
@@ -931,7 +931,7 @@
      *                             should be convertable to long as time in millis
      * @return the builder
      */
-    public DelayerType delay(Expression processAtExpression) {
+    public DelayerDefinition delay(Expression processAtExpression) {
         return delay(processAtExpression, 0L);
     }
 
@@ -944,8 +944,8 @@
      * @param delay                the delay in milliseconds which is added to the processAtExpression
      * @return the builder
      */
-    public DelayerType delay(Expression processAtExpression, long delay) {
-        DelayerType answer = new DelayerType(processAtExpression, delay);
+    public DelayerDefinition delay(Expression processAtExpression, long delay) {
+        DelayerDefinition answer = new DelayerDefinition(processAtExpression, delay);
         addOutput(answer);
         return answer;
     }
@@ -956,8 +956,8 @@
      *
      * @return the expression clause to create the expression
      */
-    public ExpressionClause<DelayerType> delay() {
-        DelayerType answer = new DelayerType();
+    public ExpressionClause<DelayerDefinition> delay() {
+        DelayerDefinition answer = new DelayerDefinition();
         addOutput(answer);
         return ExpressionClause.createAndSetExpression(answer);
     }
@@ -969,7 +969,7 @@
      * @param delay  the default delay in millis
      * @return the builder
      */
-    public DelayerType delay(long delay) {
+    public DelayerDefinition delay(long delay) {
         return delay(null, delay);
     }
 
@@ -984,8 +984,8 @@
      * @param maximumRequestCount  the maximum messages 
      * @return the builder
      */
-    public ThrottlerType throttle(long maximumRequestCount) {
-        ThrottlerType answer = new ThrottlerType(maximumRequestCount);
+    public ThrottlerDefinition throttle(long maximumRequestCount) {
+        ThrottlerDefinition answer = new ThrottlerDefinition(maximumRequestCount);
         addOutput(answer);
         return answer;
     }
@@ -997,8 +997,8 @@
      *
      * @return the clause used to create the loop expression
      */
-    public ExpressionClause<LoopType> loop() {
-        LoopType loop = new LoopType();
+    public ExpressionClause<LoopDefinition> loop() {
+        LoopDefinition loop = new LoopDefinition();
         addOutput(loop);
         return ExpressionClause.createAndSetExpression(loop);
     }
@@ -1011,8 +1011,8 @@
      * @param expression the loop expression
      * @return the builder
      */
-    public LoopType loop(Expression expression) {
-        LoopType loop = getNodeFactory().createLoop();
+    public LoopDefinition loop(Expression expression) {
+        LoopDefinition loop = getNodeFactory().createLoop();
         loop.setExpression(expression);
         addOutput(loop);
         return loop;
@@ -1026,8 +1026,8 @@
      * @param count  the number of times
      * @return the builder
      */
-    public LoopType loop(int count) {
-        LoopType loop = getNodeFactory().createLoop();
+    public LoopDefinition loop(int count) {
+        LoopDefinition loop = getNodeFactory().createLoop();
         loop.setExpression(new ConstantExpression(Integer.toString(count)));
         addOutput(loop);
         return loop;
@@ -1041,7 +1041,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type throwFault(Throwable fault) {
-        ThrowFaultType answer = new ThrowFaultType();
+        ThrowFaultDefinition answer = new ThrowFaultDefinition();
         answer.setFault(fault);
         addOutput(answer);
         return (Type) this;
@@ -1102,8 +1102,8 @@
      *
      * @return the intercept builder to configure
      */
-    public InterceptType intercept() {
-        InterceptType answer = new InterceptType();
+    public InterceptDefinition intercept() {
+        InterceptDefinition answer = new InterceptDefinition();
         addOutput(answer);
         return answer;
     }
@@ -1113,7 +1113,7 @@
      *
      * @param  interceptor  the interceptor
      */
-    public void intercept(InterceptorType interceptor) {
+    public void intercept(InterceptorDefinition interceptor) {
         addOutput(interceptor);
         pushBlock(interceptor);
     }
@@ -1123,7 +1123,7 @@
      *
      * @param interceptor  the interceptor
      */
-    public void addInterceptor(InterceptorType interceptor) {
+    public void addInterceptor(InterceptorDefinition interceptor) {
         interceptors.add(interceptor);
     }
 
@@ -1160,21 +1160,21 @@
      * <a href="http://www.enterpriseintegrationpatterns.com/Detour.html">detour</a> pattern.
      *
      * @return the builder
-     * @see ProcessorType#proceed()
+     * @see ProcessorDefinition#proceed()
      */
     @SuppressWarnings("unchecked")
     public Type proceed() {
-        ProceedType proceed = null;
-        ProcessorType currentProcessor = this;
+        ProceedDefinition proceed = null;
+        ProcessorDefinition currentProcessor = this;
 
-        if (currentProcessor instanceof InterceptType) {
-            proceed = ((InterceptType) currentProcessor).getProceed();
+        if (currentProcessor instanceof InterceptDefinition) {
+            proceed = ((InterceptDefinition) currentProcessor).getProceed();
             LOG.info("proceed() is the implied and hence not needed for an intercept()");
         }
         if (proceed == null) {
-            for (ProcessorType node = parent; node != null; node = node.getParent()) {
-                if (node instanceof InterceptType) {
-                    InterceptType intercept = (InterceptType)node;
+            for (ProcessorDefinition node = parent; node != null; node = node.getParent()) {
+                if (node instanceof InterceptDefinition) {
+                    InterceptDefinition intercept = (InterceptDefinition)node;
                     proceed = intercept.getProceed();
                     break;
                 }
@@ -1201,15 +1201,15 @@
      */
     @SuppressWarnings("unchecked")
     public Type stop() {
-        ProcessorType currentProcessor = this;
+        ProcessorDefinition currentProcessor = this;
 
-        if (currentProcessor instanceof InterceptType) {
-            ((InterceptType) currentProcessor).stopIntercept();
+        if (currentProcessor instanceof InterceptDefinition) {
+            ((InterceptDefinition) currentProcessor).stopIntercept();
         } else {
-            ProcessorType node;
+            ProcessorDefinition node;
             for (node = parent; node != null; node = node.getParent()) {
-                if (node instanceof InterceptType) {
-                    ((InterceptType) node).stopIntercept();
+                if (node instanceof InterceptDefinition) {
+                    ((InterceptDefinition) node).stopIntercept();
                     break;
                 }
             }
@@ -1228,8 +1228,8 @@
      * @param exceptionType  the exception to catch
      * @return the exception builder to configure
      */
-    public ExceptionType onException(Class exceptionType) {
-        ExceptionType answer = new ExceptionType(exceptionType);
+    public ExceptionDefinition onException(Class exceptionType) {
+        ExceptionDefinition answer = new ExceptionDefinition(exceptionType);
         addOutput(answer);
         return answer;
     }
@@ -1240,8 +1240,8 @@
      * @param predicate the predicate to test
      * @return  the choice builder to configure
      */
-    public ChoiceType intercept(Predicate predicate) {
-        InterceptType answer = new InterceptType();
+    public ChoiceDefinition intercept(Predicate predicate) {
+        InterceptDefinition answer = new InterceptDefinition();
         addOutput(answer);
         return answer.when(predicate);
     }
@@ -1280,7 +1280,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type handleFault() {
-        intercept(new HandleFaultType());
+        intercept(new HandleFaultDefinition());
         return (Type) this;
     }
 
@@ -1442,9 +1442,9 @@
      *
      * @return a expression builder clause to set the body
      */
-    public ExpressionClause<ProcessorType<Type>> setBody() {
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>(this);
-        SetBodyType answer = new SetBodyType(clause);
+    public ExpressionClause<ProcessorDefinition<Type>> setBody() {
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>(this);
+        SetBodyDefinition answer = new SetBodyDefinition(clause);
         addOutput(answer);
         return clause;
     }
@@ -1458,7 +1458,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type setBody(Expression expression) {
-        SetBodyType answer = new SetBodyType(expression);
+        SetBodyDefinition answer = new SetBodyDefinition(expression);
         addOutput(answer);
         return (Type) this;
     }
@@ -1472,7 +1472,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type transform(Expression expression) {
-        TransformType answer = new TransformType(expression);
+        TransformDefinition answer = new TransformDefinition(expression);
         addOutput(answer);
         return (Type) this;
     }
@@ -1483,9 +1483,9 @@
      *
      * @return a expression builder clause to set the body
      */
-    public ExpressionClause<ProcessorType<Type>> transform() {
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>((Type) this);
-        TransformType answer = new TransformType(clause);
+    public ExpressionClause<ProcessorDefinition<Type>> transform() {
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>((Type) this);
+        TransformDefinition answer = new TransformDefinition(clause);
         addOutput(answer);
         return clause;
     }
@@ -1506,9 +1506,9 @@
      * @param name  the header name
      * @return a expression builder clause to set the header
      */
-    public ExpressionClause<ProcessorType<Type>> setHeader(String name) {
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>(this);
-        SetHeaderType answer = new SetHeaderType(name, clause);
+    public ExpressionClause<ProcessorDefinition<Type>> setHeader(String name) {
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>(this);
+        SetHeaderDefinition answer = new SetHeaderDefinition(name, clause);
         addOutput(answer);
         return clause;
     }
@@ -1522,7 +1522,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type setHeader(String name, Expression expression) {
-        SetHeaderType answer = new SetHeaderType(name, expression);
+        SetHeaderDefinition answer = new SetHeaderDefinition(name, expression);
         addOutput(answer);
         return (Type) this;
     }
@@ -1533,9 +1533,9 @@
      * @param name  the header name
      * @return a expression builder clause to set the header
      */
-    public ExpressionClause<ProcessorType<Type>> setOutHeader(String name) {
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>(this);
-        SetOutHeaderType answer = new SetOutHeaderType(name, clause);
+    public ExpressionClause<ProcessorDefinition<Type>> setOutHeader(String name) {
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>(this);
+        SetOutHeaderDefinition answer = new SetOutHeaderDefinition(name, clause);
         addOutput(answer);
         return clause;
     }
@@ -1549,7 +1549,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type setOutHeader(String name, Expression expression) {
-        SetOutHeaderType answer = new SetOutHeaderType(name, expression);
+        SetOutHeaderDefinition answer = new SetOutHeaderDefinition(name, expression);
         addOutput(answer);
         return (Type) this;
     }
@@ -1574,7 +1574,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type setProperty(String name, Expression expression) {
-        SetPropertyType answer = new SetPropertyType(name, expression);
+        SetPropertyDefinition answer = new SetPropertyDefinition(name, expression);
         addOutput(answer);
         return (Type) this;
     }
@@ -1586,9 +1586,9 @@
      * @param name  the property name
      * @return a expression builder clause to set the property
      */
-    public ExpressionClause<ProcessorType<Type>> setProperty(String name) {
-        ExpressionClause<ProcessorType<Type>> clause = new ExpressionClause<ProcessorType<Type>>(this);
-        SetPropertyType answer = new SetPropertyType(name, clause);
+    public ExpressionClause<ProcessorDefinition<Type>> setProperty(String name) {
+        ExpressionClause<ProcessorDefinition<Type>> clause = new ExpressionClause<ProcessorDefinition<Type>>(this);
+        SetPropertyDefinition answer = new SetPropertyDefinition(name, clause);
         addOutput(answer);
         return clause;
     }
@@ -1601,7 +1601,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type removeHeader(String name) {
-        RemoveHeaderType answer = new RemoveHeaderType(name);
+        RemoveHeaderDefinition answer = new RemoveHeaderDefinition(name);
         addOutput(answer);
         return (Type) this;
     }
@@ -1624,7 +1624,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type removeProperty(String name) {
-        RemovePropertyType answer = new RemovePropertyType(name);
+        RemovePropertyDefinition answer = new RemovePropertyDefinition(name);
         addOutput(answer);
         return (Type) this;
     }
@@ -1637,7 +1637,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type convertBodyTo(Class type) {
-        addOutput(new ConvertBodyType(type));
+        addOutput(new ConvertBodyDefinition(type));
         return (Type) this;
     }
     
@@ -1649,7 +1649,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type convertBodyTo(String typeString) {
-        addOutput(new ConvertBodyType(typeString));
+        addOutput(new ConvertBodyDefinition(typeString));
         return (Type) this;
     }
 
@@ -1662,7 +1662,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type sortBody(Comparator comparator) {
-        addOutput(new SortType(body(), comparator));
+        addOutput(new SortDefinition(body(), comparator));
         return (Type) this;
     }
 
@@ -1685,7 +1685,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type sort(Expression expression, Comparator comparator) {
-        addOutput(new SortType(expression, comparator));
+        addOutput(new SortDefinition(expression, comparator));
         return (Type) this;
     }
 
@@ -1713,7 +1713,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type enrich(String resourceUri, AggregationStrategy aggregationStrategy) {
-        addOutput(new EnricherType(aggregationStrategy, resourceUri));
+        addOutput(new EnricherDefinition(aggregationStrategy, resourceUri));
         return (Type)this;
     }
     
@@ -1727,8 +1727,8 @@
      *
      * @return the expression to create the {@link DataFormat}
      */
-    public DataFormatClause<ProcessorType<Type>> unmarshal() {
-        return new DataFormatClause<ProcessorType<Type>>(this, DataFormatClause.Operation.Unmarshal);
+    public DataFormatClause<ProcessorDefinition<Type>> unmarshal() {
+        return new DataFormatClause<ProcessorDefinition<Type>>(this, DataFormatClause.Operation.Unmarshal);
     }
 
     /**
@@ -1740,8 +1740,8 @@
      * @return the builder
      */
     @SuppressWarnings("unchecked")
-    public Type unmarshal(DataFormatType dataFormatType) {
-        addOutput(new UnmarshalType(dataFormatType));
+    public Type unmarshal(DataFormatDefinition dataFormatType) {
+        addOutput(new UnmarshalDefinition(dataFormatType));
         return (Type) this;
     }
 
@@ -1754,7 +1754,7 @@
      * @return the builder
      */
     public Type unmarshal(DataFormat dataFormat) {
-        return unmarshal(new DataFormatType(dataFormat));
+        return unmarshal(new DataFormatDefinition(dataFormat));
     }
 
     /**
@@ -1768,7 +1768,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type unmarshal(String dataTypeRef) {
-        addOutput(new UnmarshalType(dataTypeRef));
+        addOutput(new UnmarshalDefinition(dataTypeRef));
         return (Type) this;
     }
 
@@ -1779,8 +1779,8 @@
      *
      * @return the expression to create the {@link DataFormat}
      */
-    public DataFormatClause<ProcessorType<Type>> marshal() {
-        return new DataFormatClause<ProcessorType<Type>>(this, DataFormatClause.Operation.Marshal);
+    public DataFormatClause<ProcessorDefinition<Type>> marshal() {
+        return new DataFormatClause<ProcessorDefinition<Type>>(this, DataFormatClause.Operation.Marshal);
     }
 
     /**
@@ -1792,8 +1792,8 @@
      * @return the builder
      */
     @SuppressWarnings("unchecked")
-    public Type marshal(DataFormatType dataFormatType) {
-        addOutput(new MarshalType(dataFormatType));
+    public Type marshal(DataFormatDefinition dataFormatType) {
+        addOutput(new MarshalDefinition(dataFormatType));
         return (Type) this;
     }
 
@@ -1806,7 +1806,7 @@
      * @return the builder
      */
     public Type marshal(DataFormat dataFormat) {
-        return marshal(new DataFormatType(dataFormat));
+        return marshal(new DataFormatDefinition(dataFormat));
     }
 
     /**
@@ -1820,7 +1820,7 @@
      */
     @SuppressWarnings("unchecked")
     public Type marshal(String dataTypeRef) {
-        addOutput(new MarshalType(dataTypeRef));
+        addOutput(new MarshalDefinition(dataTypeRef));
         return (Type) this;
     }
 
@@ -1828,11 +1828,11 @@
     // -------------------------------------------------------------------------
     @XmlTransient
     @SuppressWarnings("unchecked")
-    public ProcessorType<? extends ProcessorType> getParent() {
+    public ProcessorDefinition<? extends ProcessorDefinition> getParent() {
         return parent;
     }
 
-    public void setParent(ProcessorType<? extends ProcessorType> parent) {
+    public void setParent(ProcessorDefinition<? extends ProcessorDefinition> parent) {
         this.parent = parent;
     }
 
@@ -1947,7 +1947,7 @@
             }
         }
 
-        List<InterceptorType> list = routeContext.getRoute().getInterceptors();
+        List<InterceptorDefinition> list = routeContext.getRoute().getInterceptors();
         if (interceptors != null) {
             list.addAll(interceptors);
         }
@@ -1955,7 +1955,7 @@
         Collections.reverse(list);
         Set<Processor> interceptors = new HashSet<Processor>();
         interceptors.add(target);
-        for (InterceptorType interceptorType : list) {
+        for (InterceptorDefinition interceptorType : list) {
             DelegateProcessor interceptor = interceptorType.createInterceptor(routeContext);
             if (!interceptors.contains(interceptor)) {
                 interceptors.add(interceptor);
@@ -1997,12 +1997,12 @@
         }
     }
 
-    protected void configureChild(ProcessorType output) {
+    protected void configureChild(ProcessorDefinition output) {
         output.setNodeFactory(getNodeFactory());
     }
 
     @SuppressWarnings("unchecked")
-    public void addOutput(ProcessorType processorType) {
+    public void addOutput(ProcessorDefinition processorType) {
         processorType.setParent(this);
         configureChild(processorType);
         if (blocks.isEmpty()) {
@@ -2022,19 +2022,19 @@
         return new Pipeline(list);
     }
 
-    protected Processor createOutputsProcessor(RouteContext routeContext, Collection<ProcessorType> outputs)
+    protected Processor createOutputsProcessor(RouteContext routeContext, Collection<ProcessorDefinition> outputs)
         throws Exception {
         List<Processor> list = new ArrayList<Processor>();
-        for (ProcessorType output : outputs) {
+        for (ProcessorDefinition output : outputs) {
             Processor processor = output.createProcessor(routeContext);
             // if the ProceedType/StopType create processor is null we keep on going
-            if ((output instanceof ProceedType || output instanceof StopType) && processor == null) {
+            if ((output instanceof ProceedDefinition || output instanceof StopDefinition) && processor == null) {
                 continue;
             }
             processor = output.wrapProcessorInInterceptors(routeContext, processor);
 
-            ProcessorType currentProcessor = this;
-            if (!(currentProcessor instanceof ExceptionType || currentProcessor instanceof TryType)) {
+            ProcessorDefinition currentProcessor = this;
+            if (!(currentProcessor instanceof ExceptionDefinition || currentProcessor instanceof TryDefinition)) {
                 processor = output.wrapInErrorHandler(routeContext, processor);
             }
 

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorRef.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorRef.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorRef.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/ProcessorRef.java Fri Mar  6 08:20:00 2009
@@ -33,7 +33,7 @@
  */
 @XmlRootElement(name = "process")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class ProcessorRef extends OutputType<ProcessorType> {
+public class ProcessorRef extends OutputDefinition<ProcessorDefinition> {
     @XmlAttribute(required = true)
     private String ref;
     @XmlTransient

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RecipientListDefinition.java Fri Mar  6 08:20:00 2009
@@ -25,7 +25,7 @@
 import org.apache.camel.Processor;
 import org.apache.camel.builder.ExpressionBuilder;
 import org.apache.camel.builder.ExpressionClause;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.processor.RecipientList;
 import org.apache.camel.spi.RouteContext;
 
@@ -36,19 +36,19 @@
  */
 @XmlRootElement(name = "recipientList")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RecipientListType extends ExpressionNode {
+public class RecipientListDefinition extends ExpressionNode {
 
     @XmlAttribute(required = false)
     private String delimiter;
 
-    public RecipientListType() {
+    public RecipientListDefinition() {
     }
 
-    public RecipientListType(ExpressionType expression) {
+    public RecipientListDefinition(ExpressionDefinition expression) {
         super(expression);
     }
 
-    public RecipientListType(Expression expression) {
+    public RecipientListDefinition(Expression expression) {
         super(expression);
     }
 
@@ -80,7 +80,7 @@
      * Set the expression that RecipientListType will use
      * @return the builder
      */
-    public ExpressionClause<RecipientListType> expression() {
+    public ExpressionClause<RecipientListDefinition> expression() {
         return ExpressionClause.createAndSetExpression(this);
     }
 

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RedeliveryPolicyDefinition.java Fri Mar  6 08:20:00 2009
@@ -33,7 +33,7 @@
  */
 @XmlRootElement(name = "redeliveryPolicy")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RedeliveryPolicyType {
+public class RedeliveryPolicyDefinition {
     @XmlAttribute()
     private String ref;
     @XmlAttribute
@@ -106,7 +106,7 @@
      * @param backOffMultiplier  the back off multiplier
      * @return the builder
      */
-    public RedeliveryPolicyType backOffMultiplier(double backOffMultiplier) {
+    public RedeliveryPolicyDefinition backOffMultiplier(double backOffMultiplier) {
         setBackOffMultiplier(backOffMultiplier);
         return this;
     }
@@ -117,7 +117,7 @@
      * @param collisionAvoidancePercent  the percentage
      * @return the builder
      */
-    public RedeliveryPolicyType collisionAvoidancePercent(double collisionAvoidancePercent) {
+    public RedeliveryPolicyDefinition collisionAvoidancePercent(double collisionAvoidancePercent) {
         setCollisionAvoidanceFactor(collisionAvoidancePercent * 0.01d);
         return this;
     }
@@ -128,7 +128,7 @@
      * @param collisionAvoidanceFactor  the factor
      * @return the builder
      */
-    public RedeliveryPolicyType collisionAvoidanceFactor(double collisionAvoidanceFactor) {
+    public RedeliveryPolicyDefinition collisionAvoidanceFactor(double collisionAvoidanceFactor) {
         setCollisionAvoidanceFactor(collisionAvoidanceFactor);
         return this;
     }
@@ -139,7 +139,7 @@
      * @param delay  delay in millis
      * @return the builder
      */
-    public RedeliveryPolicyType redeliveryDelay(long delay) {
+    public RedeliveryPolicyDefinition redeliveryDelay(long delay) {
         setRedeliveryDelay(delay);
         return this;
     }
@@ -150,7 +150,7 @@
      * @param retriesExhaustedLogLevel  the logging level
      * @return the builder
      */
-    public RedeliveryPolicyType retriesExhaustedLogLevel(LoggingLevel retriesExhaustedLogLevel) {
+    public RedeliveryPolicyDefinition retriesExhaustedLogLevel(LoggingLevel retriesExhaustedLogLevel) {
         setRetriesExhaustedLogLevel(retriesExhaustedLogLevel);
         return this;
     }    
@@ -161,7 +161,7 @@
      * @param retryAttemptedLogLevel  the logging level
      * @return the builder
      */
-    public RedeliveryPolicyType retryAttemptedLogLevel(LoggingLevel retryAttemptedLogLevel) {
+    public RedeliveryPolicyDefinition retryAttemptedLogLevel(LoggingLevel retryAttemptedLogLevel) {
         setRetryAttemptedLogLevel(retryAttemptedLogLevel);
         return this;
     }
@@ -177,7 +177,7 @@
      * @param maximumRedeliveries  the value
      * @return the builder
      */
-    public RedeliveryPolicyType maximumRedeliveries(int maximumRedeliveries) {
+    public RedeliveryPolicyDefinition maximumRedeliveries(int maximumRedeliveries) {
         setMaximumRedeliveries(maximumRedeliveries);
         return this;
     }
@@ -187,7 +187,7 @@
      *
      * @return the builder
      */
-    public RedeliveryPolicyType useCollisionAvoidance() {
+    public RedeliveryPolicyDefinition useCollisionAvoidance() {
         setUseCollisionAvoidance(Boolean.TRUE);
         return this;
     }
@@ -197,7 +197,7 @@
      *
      * @return the builder
      */
-    public RedeliveryPolicyType useExponentialBackOff() {
+    public RedeliveryPolicyDefinition useExponentialBackOff() {
         setUseExponentialBackOff(Boolean.TRUE);
         return this;
     }
@@ -208,7 +208,7 @@
      * @param maximumRedeliveryDelay  the delay in millis
      * @return the builder
      */
-    public RedeliveryPolicyType maximumRedeliveryDelay(long maximumRedeliveryDelay) {
+    public RedeliveryPolicyDefinition maximumRedeliveryDelay(long maximumRedeliveryDelay) {
         setMaximumRedeliveryDelay(maximumRedeliveryDelay);
         return this;
     }
@@ -219,7 +219,7 @@
      * @param ref  reference to the redelivery policy to lookup and use
      * @return the builder
      */
-    public RedeliveryPolicyType ref(String ref) {
+    public RedeliveryPolicyDefinition ref(String ref) {
         setRef(ref);
         return this;
     }

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemoveHeaderDefinition.java Fri Mar  6 08:20:00 2009
@@ -31,14 +31,14 @@
  */
 @XmlRootElement(name = "removeHeader")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RemoveHeaderType extends OutputType<ProcessorType> {
+public class RemoveHeaderDefinition extends OutputDefinition<ProcessorDefinition> {
     @XmlAttribute(required = true)
     private String headerName;   
     
-    public RemoveHeaderType() {
+    public RemoveHeaderDefinition() {
     }
     
-    public RemoveHeaderType(String headerName) {
+    public RemoveHeaderDefinition(String headerName) {
         setHeaderName(headerName);
     }
     

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java Fri Mar  6 08:20:00 2009
@@ -31,14 +31,14 @@
  */
 @XmlRootElement(name = "removeProperty")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RemovePropertyType extends OutputType<ProcessorType> {
+public class RemovePropertyDefinition extends OutputDefinition<ProcessorDefinition> {
     @XmlAttribute(required = true)
     private String propertyName;   
     
-    public RemovePropertyType() {
+    public RemovePropertyDefinition() {
     }
     
-    public RemovePropertyType(String propertyName) {
+    public RemovePropertyDefinition(String propertyName) {
         setPropertyName(propertyName);
     }
     

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/ResequencerDefinition.java Fri Mar  6 08:20:00 2009
@@ -28,7 +28,7 @@
 import org.apache.camel.Processor;
 import org.apache.camel.model.config.BatchResequencerConfig;
 import org.apache.camel.model.config.StreamResequencerConfig;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.processor.Resequencer;
 import org.apache.camel.processor.StreamResequencer;
 import org.apache.camel.processor.resequencer.ExpressionResultComparator;
@@ -40,11 +40,11 @@
  * @version $Revision$
  */
 @XmlRootElement(name = "resequence")
-public class ResequencerType extends ProcessorType<ProcessorType> {
+public class ResequencerDefinition extends ProcessorDefinition<ProcessorDefinition> {
     @XmlElementRef
-    private List<ExpressionType> expressions = new ArrayList<ExpressionType>();
+    private List<ExpressionDefinition> expressions = new ArrayList<ExpressionDefinition>();
     @XmlElementRef
-    private List<ProcessorType> outputs = new ArrayList<ProcessorType>();
+    private List<ProcessorDefinition> outputs = new ArrayList<ProcessorDefinition>();
     // Binding annotation at setter
     private BatchResequencerConfig batchConfig;
     // Binding annotation at setter
@@ -52,11 +52,11 @@
     @XmlTransient
     private List<Expression> expressionList;
 
-    public ResequencerType() {
+    public ResequencerDefinition() {
         this(null);
     }
 
-    public ResequencerType(List<Expression> expressions) {
+    public ResequencerDefinition(List<Expression> expressions) {
         this.expressionList = expressions;
         this.batch();
     }
@@ -74,7 +74,7 @@
      *
      * @return the builder
      */
-    public ResequencerType stream() {
+    public ResequencerDefinition stream() {
         return stream(StreamResequencerConfig.getDefault());
     }
 
@@ -84,7 +84,7 @@
      *
      * @return the builder
      */
-    public ResequencerType batch() {
+    public ResequencerDefinition batch() {
         return batch(BatchResequencerConfig.getDefault());
     }
 
@@ -95,7 +95,7 @@
      * @param config  the config
      * @return the builder
      */
-    public ResequencerType stream(StreamResequencerConfig config) {
+    public ResequencerDefinition stream(StreamResequencerConfig config) {
         this.streamConfig = config;
         this.batchConfig = null;
         return this;
@@ -108,7 +108,7 @@
      * @param config  the config
      * @return the builder
      */
-    public ResequencerType batch(BatchResequencerConfig config) {
+    public ResequencerDefinition batch(BatchResequencerConfig config) {
         this.batchConfig = config;
         this.streamConfig = null;
         return this;
@@ -120,7 +120,7 @@
      * @param expression  the expression
      * @return the builder
      */
-    public ResequencerType expression(ExpressionType expression) {
+    public ResequencerDefinition expression(ExpressionDefinition expression) {
         expressions.add(expression);
         return this;
     }
@@ -130,7 +130,7 @@
      * @param timeout  timeout in millis
      * @return the builder
      */
-    public ResequencerType timeout(long timeout) {
+    public ResequencerDefinition timeout(long timeout) {
         if (batchConfig != null) {
             batchConfig.setBatchTimeout(timeout);
         } else {
@@ -144,7 +144,7 @@
      * @param batchSize  the batch size
      * @return the builder
      */
-    public ResequencerType size(int batchSize) {
+    public ResequencerDefinition size(int batchSize) {
         if (batchConfig == null) {
             throw new IllegalStateException("size() only supported for batch resequencer");
         }
@@ -158,7 +158,7 @@
      * @param capacity  the capacity
      * @return the builder
      */
-    public ResequencerType capacity(int capacity) {
+    public ResequencerDefinition capacity(int capacity) {
         if (streamConfig == null) {
             throw new IllegalStateException("capacity() only supported for stream resequencer");
         }
@@ -173,7 +173,7 @@
      * @param comparator  the comparator
      * @return the builder
      */
-    public ResequencerType comparator(ExpressionResultComparator comparator) {
+    public ResequencerDefinition comparator(ExpressionResultComparator comparator) {
         if (streamConfig == null) {
             throw new IllegalStateException("comparator() only supported for stream resequencer");
         }
@@ -188,18 +188,18 @@
 
     @Override
     public String getLabel() {
-        return ExpressionType.getLabel(getExpressions());
+        return ExpressionDefinition.getLabel(getExpressions());
     }
 
-    public List<ExpressionType> getExpressions() {
+    public List<ExpressionDefinition> getExpressions() {
         return expressions;
     }
 
-    public List<ProcessorType> getOutputs() {
+    public List<ProcessorDefinition> getOutputs() {
         return outputs;
     }
 
-    public void setOutputs(List<ProcessorType> outputs) {
+    public void setOutputs(List<ProcessorDefinition> outputs) {
         this.outputs = outputs;
     }
 
@@ -276,7 +276,7 @@
     private List<Expression> resolveExpressionList(RouteContext routeContext) {
         if (expressionList == null) {
             expressionList = new ArrayList<Expression>();
-            for (ExpressionType expression : expressions) {
+            for (ExpressionDefinition expression : expressions) {
                 expressionList.add(expression.createExpression(routeContext));
             }
         }

Modified: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java?rev=750806&r1=750805&r2=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteDefinition.java Fri Mar  6 08:20:00 2009
@@ -50,23 +50,23 @@
 @XmlRootElement(name = "route")
 @XmlType(propOrder = {"inputs", "outputs" })
 @XmlAccessorType(XmlAccessType.PROPERTY)
-public class RouteType extends ProcessorType<ProcessorType> implements CamelContextAware {
-    private static final transient Log LOG = LogFactory.getLog(RouteType.class);
-    private List<InterceptorType> interceptors = new ArrayList<InterceptorType>();
-    private List<FromType> inputs = new ArrayList<FromType>();
-    private List<ProcessorType> outputs = new ArrayList<ProcessorType>();
+public class RouteDefinition extends ProcessorDefinition<ProcessorDefinition> implements CamelContextAware {
+    private static final transient Log LOG = LogFactory.getLog(RouteDefinition.class);
+    private List<InterceptorDefinition> interceptors = new ArrayList<InterceptorDefinition>();
+    private List<FromDefinition> inputs = new ArrayList<FromDefinition>();
+    private List<ProcessorDefinition> outputs = new ArrayList<ProcessorDefinition>();
     private String group;
     private CamelContext camelContext;
     private Boolean streamCaching;
 
-    public RouteType() {
+    public RouteDefinition() {
     }
 
-    public RouteType(String uri) {
+    public RouteDefinition(String uri) {
         from(uri);
     }
 
-    public RouteType(Endpoint endpoint) {
+    public RouteDefinition(Endpoint endpoint) {
         from(endpoint);
     }
 
@@ -117,7 +117,7 @@
             setErrorHandlerBuilderIfNull(handler);
         }
 
-        for (FromType fromType : inputs) {
+        for (FromDefinition fromType : inputs) {
             RouteContext routeContext = addRoutes(routes, fromType);
             answer.add(routeContext);
         }
@@ -142,8 +142,8 @@
      * @param uri  the from uri
      * @return the builder
      */
-    public RouteType from(String uri) {
-        getInputs().add(new FromType(uri));
+    public RouteDefinition from(String uri) {
+        getInputs().add(new FromDefinition(uri));
         return this;
     }
 
@@ -153,8 +153,8 @@
      * @param endpoint  the from endpoint
      * @return the builder
      */
-    public RouteType from(Endpoint endpoint) {
-        getInputs().add(new FromType(endpoint));
+    public RouteDefinition from(Endpoint endpoint) {
+        getInputs().add(new FromDefinition(endpoint));
         return this;
     }
 
@@ -164,9 +164,9 @@
      * @param uris  the from uris
      * @return the builder
      */
-    public RouteType from(String... uris) {
+    public RouteDefinition from(String... uris) {
         for (String uri : uris) {
-            getInputs().add(new FromType(uri));
+            getInputs().add(new FromDefinition(uri));
         }
         return this;
     }
@@ -177,9 +177,9 @@
      * @param endpoints  the from endpoints
      * @return the builder
      */
-    public RouteType from(Endpoint... endpoints) {
+    public RouteDefinition from(Endpoint... endpoints) {
         for (Endpoint endpoint : endpoints) {
-            getInputs().add(new FromType(endpoint));
+            getInputs().add(new FromDefinition(endpoint));
         }
         return this;
     }
@@ -190,7 +190,7 @@
      * @param name  the group name
      * @return the builder
      */
-    public RouteType group(String name) {
+    public RouteDefinition group(String name) {
         setGroup(name);
         return this;
     }
@@ -200,7 +200,7 @@
      *
      * @return the builder
      */
-    public RouteType noStreamCaching() {
+    public RouteDefinition noStreamCaching() {
         StreamCachingInterceptor.noStreamCaching(interceptors);
         return this;
     }
@@ -210,7 +210,7 @@
      *
      * @return the builder
      */
-    public RouteType streamCaching() {
+    public RouteDefinition streamCaching() {
         addInterceptor(new StreamCachingInterceptor());
         return this;
     }
@@ -218,35 +218,35 @@
     // Properties
     // -----------------------------------------------------------------------
 
-    public List<InterceptorType> getInterceptors() {
+    public List<InterceptorDefinition> getInterceptors() {
         return interceptors;
     }
 
     @XmlTransient
-    public void setInterceptors(List<InterceptorType> interceptors) {
+    public void setInterceptors(List<InterceptorDefinition> interceptors) {
         this.interceptors = interceptors;
     }
 
-    public List<FromType> getInputs() {
+    public List<FromDefinition> getInputs() {
         return inputs;
     }
 
     @XmlElementRef
-    public void setInputs(List<FromType> inputs) {
+    public void setInputs(List<FromDefinition> inputs) {
         this.inputs = inputs;
     }
 
-    public List<ProcessorType> getOutputs() {
+    public List<ProcessorDefinition> getOutputs() {
         return outputs;
     }
 
     @XmlElementRef
-    public void setOutputs(List<ProcessorType> outputs) {
+    public void setOutputs(List<ProcessorDefinition> outputs) {
         this.outputs = outputs;
 
         // TODO I don't think this is called when using JAXB!
         if (outputs != null) {
-            for (ProcessorType output : outputs) {
+            for (ProcessorDefinition output : outputs) {
                 configureChild(output);
             }
         }
@@ -297,15 +297,15 @@
 
     // Implementation methods
     // -------------------------------------------------------------------------
-    protected RouteContext addRoutes(Collection<Route> routes, FromType fromType) throws Exception {
+    protected RouteContext addRoutes(Collection<Route> routes, FromDefinition fromType) throws Exception {
         RouteContext routeContext = new DefaultRouteContext(this, fromType, routes);
         routeContext.getEndpoint(); // force endpoint resolution
         if (camelContext != null) {
             camelContext.getLifecycleStrategy().onRouteContextCreate(routeContext);
         }
 
-        List<ProcessorType> list = new ArrayList<ProcessorType>(outputs);
-        for (ProcessorType output : list) {
+        List<ProcessorDefinition> list = new ArrayList<ProcessorDefinition>(outputs);
+        for (ProcessorDefinition output : list) {
             output.addRoutes(routeContext, routes);
         }
 
@@ -314,21 +314,21 @@
     }
 
     @Override
-    protected void configureChild(ProcessorType output) {
+    protected void configureChild(ProcessorDefinition output) {
         super.configureChild(output);
 
         if (isInheritErrorHandler()) {
             output.setErrorHandlerBuilder(getErrorHandlerBuilder());
         }
 
-        List<InterceptorType> interceptors = getInterceptors();
-        for (InterceptorType interceptor : interceptors) {
+        List<InterceptorDefinition> interceptors = getInterceptors();
+        for (InterceptorDefinition interceptor : interceptors) {
             output.addInterceptor(interceptor);
         }
     }
 
     @Override
-    public void addInterceptor(InterceptorType interceptor) {
+    public void addInterceptor(InterceptorDefinition interceptor) {
         getInterceptors().add(interceptor);
     }
 

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutesDefinition.java Fri Mar  6 08:20:00 2009
@@ -39,18 +39,18 @@
  */
 @XmlRootElement(name = "routes")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RoutesType extends OptionalIdentifiedType<RoutesType> implements RouteContainer {
+public class RoutesDefinition extends OptionalIdentifiedType<RoutesDefinition> implements RouteContainer {
     // TODO: not sure how else to use an optional attribute in JAXB2
     @XmlAttribute
     private Boolean inheritErrorHandlerFlag;
     @XmlElementRef
-    private List<RouteType> routes = new ArrayList<RouteType>();
+    private List<RouteDefinition> routes = new ArrayList<RouteDefinition>();
     @XmlTransient
-    private List<InterceptorType> interceptors = new ArrayList<InterceptorType>();
+    private List<InterceptorDefinition> interceptors = new ArrayList<InterceptorDefinition>();
     @XmlTransient
-    private List<InterceptType> intercepts = new ArrayList<InterceptType>();
+    private List<InterceptDefinition> intercepts = new ArrayList<InterceptDefinition>();
     @XmlTransient
-    private List<ExceptionType> exceptions = new ArrayList<ExceptionType>();
+    private List<ExceptionDefinition> exceptions = new ArrayList<ExceptionDefinition>();
     @XmlTransient
     private CamelContext camelContext;
     @XmlTransient
@@ -63,35 +63,35 @@
 
     // Properties
     //-----------------------------------------------------------------------
-    public List<RouteType> getRoutes() {
+    public List<RouteDefinition> getRoutes() {
         return routes;
     }
 
-    public void setRoutes(List<RouteType> routes) {
+    public void setRoutes(List<RouteDefinition> routes) {
         this.routes = routes;
     }
 
-    public List<InterceptorType> getInterceptors() {
+    public List<InterceptorDefinition> getInterceptors() {
         return interceptors;
     }
 
-    public void setInterceptors(List<InterceptorType> interceptors) {
+    public void setInterceptors(List<InterceptorDefinition> interceptors) {
         this.interceptors = interceptors;
     }
 
-    public List<InterceptType> getIntercepts() {
+    public List<InterceptDefinition> getIntercepts() {
         return intercepts;
     }
 
-    public void setIntercepts(List<InterceptType> intercepts) {
+    public void setIntercepts(List<InterceptDefinition> intercepts) {
         this.intercepts = intercepts;
     }
 
-    public List<ExceptionType> getExceptions() {
+    public List<ExceptionDefinition> getExceptions() {
         return exceptions;
     }
 
-    public void setExceptions(List<ExceptionType> exceptions) {
+    public void setExceptions(List<ExceptionDefinition> exceptions) {
         this.exceptions = exceptions;
     }
 
@@ -104,7 +104,7 @@
     }
 
     public boolean isInheritErrorHandler() {
-        return ProcessorType.isInheritErrorHandler(getInheritErrorHandlerFlag());
+        return ProcessorDefinition.isInheritErrorHandler(getInheritErrorHandlerFlag());
     }
 
     public Boolean getInheritErrorHandlerFlag() {
@@ -131,8 +131,8 @@
      *
      * @return the builder
      */
-    public RouteType route() {
-        RouteType route = createRoute();
+    public RouteDefinition route() {
+        RouteDefinition route = createRoute();
         return route(route);
     }
 
@@ -142,8 +142,8 @@
      * @param uri  the from uri
      * @return the builder
      */
-    public RouteType from(String uri) {
-        RouteType route = createRoute();
+    public RouteDefinition from(String uri) {
+        RouteDefinition route = createRoute();
         route.from(uri);
         return route(route);
     }
@@ -154,8 +154,8 @@
      * @param endpoint  the from endpoint
      * @return the builder
      */
-    public RouteType from(Endpoint endpoint) {
-        RouteType route = createRoute();
+    public RouteDefinition from(Endpoint endpoint) {
+        RouteDefinition route = createRoute();
         route.from(endpoint);
         return route(route);
     }
@@ -166,8 +166,8 @@
      * @param uris  the from uri
      * @return the builder
      */
-    public RouteType from(String... uris) {
-        RouteType route = createRoute();
+    public RouteDefinition from(String... uris) {
+        RouteDefinition route = createRoute();
         route.from(uris);
         return route(route);
     }
@@ -178,8 +178,8 @@
      * @param endpoints  the from endpoints
      * @return the builder
      */
-    public RouteType from(Endpoint... endpoints) {
-        RouteType route = createRoute();
+    public RouteDefinition from(Endpoint... endpoints) {
+        RouteDefinition route = createRoute();
         route.from(endpoints);
         return route(route);
     }
@@ -190,19 +190,19 @@
      * @param route the route
      * @return the builder
      */
-    public RouteType route(RouteType route) {
+    public RouteDefinition route(RouteDefinition route) {
         // lets configure the route
         route.setCamelContext(getCamelContext());
         route.setInheritErrorHandlerFlag(getInheritErrorHandlerFlag());
-        List<InterceptorType> list = getInterceptors();
-        for (InterceptorType interceptorType : list) {
+        List<InterceptorDefinition> list = getInterceptors();
+        for (InterceptorDefinition interceptorType : list) {
             route.addInterceptor(interceptorType);
         }
-        List<InterceptType> intercepts = getIntercepts();
-        for (InterceptType intercept : intercepts) {
+        List<InterceptDefinition> intercepts = getIntercepts();
+        for (InterceptDefinition intercept : intercepts) {
             // need to create a proxy for this one and use the
             // proceed of the proxy which will be local to this route
-            InterceptType proxy = intercept.createProxy();
+            InterceptDefinition proxy = intercept.createProxy();
             route.addOutput(proxy);
             route.pushBlock(proxy.getProceed());
         }
@@ -217,7 +217,7 @@
      * @param interceptor  the interceptor
      * @return the builder
      */
-    public RoutesType intercept(DelegateProcessor interceptor) {
+    public RoutesDefinition intercept(DelegateProcessor interceptor) {
         getInterceptors().add(new InterceptorRef(interceptor));
         return this;
     }
@@ -227,8 +227,8 @@
      *
      * @return the interceptor builder to configure
      */
-    public InterceptType intercept() {
-        InterceptType answer = new InterceptType();
+    public InterceptDefinition intercept() {
+        InterceptDefinition answer = new InterceptDefinition();
         getIntercepts().add(answer);
         return answer;
     }
@@ -239,8 +239,8 @@
      * @param predicate  the predicate
      * @return the builder
      */
-    public ChoiceType intercept(Predicate predicate) {
-        InterceptType answer = new InterceptType();
+    public ChoiceDefinition intercept(Predicate predicate) {
+        InterceptDefinition answer = new InterceptDefinition();
         getIntercepts().add(answer);
         return answer.when(predicate);
     }
@@ -251,16 +251,16 @@
      * @param exception  the exception
      * @return the builder
      */
-    public ExceptionType onException(Class exception) {
-        ExceptionType answer = new ExceptionType(exception);
+    public ExceptionDefinition onException(Class exception) {
+        ExceptionDefinition answer = new ExceptionDefinition(exception);
         getExceptions().add(answer);
         return answer;
     }
 
     // Implementation methods
     //-------------------------------------------------------------------------
-    protected RouteType createRoute() {
-        RouteType route = new RouteType();
+    protected RouteDefinition createRoute() {
+        RouteDefinition route = new RouteDefinition();
         ErrorHandlerBuilder handler = getErrorHandlerBuilder();
         if (isInheritErrorHandler() && handler != null) {
             route.setErrorHandlerBuilderIfNull(handler);

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RoutingSlipDefinition.java Fri Mar  6 08:20:00 2009
@@ -34,7 +34,7 @@
  */
 @XmlRootElement(name = "routingSlip")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class RoutingSlipType extends ProcessorType<ProcessorType> {
+public class RoutingSlipDefinition extends ProcessorDefinition<ProcessorDefinition> {
     public static final String DEFAULT_DELIMITER = ",";
 
     @XmlAttribute
@@ -42,15 +42,15 @@
     @XmlAttribute
     private String uriDelimiter;
 
-    public RoutingSlipType() {
+    public RoutingSlipDefinition() {
         this(null, DEFAULT_DELIMITER);
     }
 
-    public RoutingSlipType(String headerName) {
+    public RoutingSlipDefinition(String headerName) {
         this(headerName, DEFAULT_DELIMITER);
     }
 
-    public RoutingSlipType(String headerName, String uriDelimiter) {
+    public RoutingSlipDefinition(String headerName, String uriDelimiter) {
         setHeaderName(headerName);
         setUriDelimiter(uriDelimiter);
     }
@@ -74,7 +74,7 @@
 
     @Override
     @SuppressWarnings("unchecked")
-    public List<ProcessorType> getOutputs() {
+    public List<ProcessorDefinition> getOutputs() {
         return Collections.EMPTY_LIST;
     }
 

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/SendDefinition.java Fri Mar  6 08:20:00 2009
@@ -38,7 +38,7 @@
  */
 //@XmlType(name = "sendType")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class SendType<Type extends ProcessorType> extends ProcessorType<Type> {
+public class SendDefinition<Type extends ProcessorDefinition> extends ProcessorDefinition<Type> {
     @XmlAttribute(required = false)
     private String uri;
     @XmlAttribute(required = false)
@@ -90,7 +90,7 @@
     }
 
     @SuppressWarnings("unchecked")
-    public List<ProcessorType> getOutputs() {
+    public List<ProcessorDefinition> getOutputs() {
         return Collections.EMPTY_LIST;
     }
 
@@ -109,6 +109,6 @@
 
     @Override
     public String getLabel() {
-        return FromType.description(getUri(), getRef(), getEndpoint());
+        return FromDefinition.description(getUri(), getRef(), getEndpoint());
     }
 }

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetBodyDefinition.java Fri Mar  6 08:20:00 2009
@@ -32,12 +32,12 @@
  */
 @XmlRootElement(name = "setBody")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class SetBodyType extends ExpressionNode {
+public class SetBodyDefinition extends ExpressionNode {
 
-    public SetBodyType() {
+    public SetBodyDefinition() {
     }
 
-    public SetBodyType(Expression expression) {
+    public SetBodyDefinition(Expression expression) {
         super(expression);
     }
 
@@ -63,7 +63,7 @@
      * Set the expression that SetBodyType class will use
      * @return the builder
      */
-    public ExpressionClause<SetBodyType> expression() {
+    public ExpressionClause<SetBodyDefinition> expression() {
         return ExpressionClause.createAndSetExpression(this);
     }
 }

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetExchangePatternDefinition.java Fri Mar  6 08:20:00 2009
@@ -38,20 +38,20 @@
  */
 @XmlRootElement(name = "setExchangePattern")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class SetExchangePatternType extends OutputType {
+public class SetExchangePatternDefinition extends OutputDefinition {
     @XmlAttribute(required = true)
     private ExchangePattern pattern;
     @XmlTransient
     private ExchangePatternProcessor processor;
     
-    public SetExchangePatternType() {
+    public SetExchangePatternDefinition() {
     }
 
-    public SetExchangePatternType(ExchangePattern pattern) {
+    public SetExchangePatternDefinition(ExchangePattern pattern) {
         this.pattern = pattern;
     }
 
-    public SetExchangePatternType pattern(ExchangePattern pattern) {
+    public SetExchangePatternDefinition pattern(ExchangePattern pattern) {
         setPattern(pattern);
         return this;
     }

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetHeaderDefinition.java Fri Mar  6 08:20:00 2009
@@ -26,7 +26,7 @@
 import org.apache.camel.builder.ExpressionBuilder;
 import org.apache.camel.builder.ExpressionClause;
 import org.apache.camel.builder.ProcessorBuilder;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.spi.RouteContext;
 import org.apache.camel.util.ObjectHelper;
 
@@ -35,24 +35,24 @@
  */
 @XmlRootElement(name = "setHeader")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class SetHeaderType extends ExpressionNode {
+public class SetHeaderDefinition extends ExpressionNode {
     @XmlAttribute(required = true)
     private String headerName;
     
-    public SetHeaderType() {
+    public SetHeaderDefinition() {
     }
 
-    public SetHeaderType(String headerName, ExpressionType expression) {
+    public SetHeaderDefinition(String headerName, ExpressionDefinition expression) {
         super(expression);
         setHeaderName(headerName);
     }
 
-    public SetHeaderType(String headerName, Expression expression) {
+    public SetHeaderDefinition(String headerName, Expression expression) {
         super(expression);
         setHeaderName(headerName);        
     }
 
-    public SetHeaderType(String headerName, String value) {
+    public SetHeaderDefinition(String headerName, String value) {
         super(ExpressionBuilder.constantExpression(value));
         setHeaderName(headerName);        
     }   
@@ -88,7 +88,7 @@
      * Set the expression that SetHeaderType will use
      * @return the builder
      */
-    public ExpressionClause<SetHeaderType> expression() {
+    public ExpressionClause<SetHeaderDefinition> expression() {
         return ExpressionClause.createAndSetExpression(this);
     }
 }

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderType.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/SetOutHeaderDefinition.java Fri Mar  6 08:20:00 2009
@@ -25,7 +25,7 @@
 import org.apache.camel.Processor;
 import org.apache.camel.builder.ExpressionClause;
 import org.apache.camel.builder.ProcessorBuilder;
-import org.apache.camel.model.language.ExpressionType;
+import org.apache.camel.model.language.ExpressionDefinition;
 import org.apache.camel.spi.RouteContext;
 import org.apache.camel.util.ObjectHelper;
 
@@ -34,19 +34,19 @@
  */
 @XmlRootElement(name = "setOutHeader")
 @XmlAccessorType(XmlAccessType.FIELD)
-public class SetOutHeaderType extends ExpressionNode {
+public class SetOutHeaderDefinition extends ExpressionNode {
     @XmlAttribute(required = true)
     private String headerName;
     
-    public SetOutHeaderType() {
+    public SetOutHeaderDefinition() {
     }
 
-    public SetOutHeaderType(String headerName, ExpressionType expression) {
+    public SetOutHeaderDefinition(String headerName, ExpressionDefinition expression) {
         super(expression);
         setHeaderName(headerName);
     }
 
-    public SetOutHeaderType(String headerName, Expression expression) {
+    public SetOutHeaderDefinition(String headerName, Expression expression) {
         super(expression);
         setHeaderName(headerName);        
     }
@@ -82,7 +82,7 @@
      * Set the expression that SetOutHeaderType will use
      * @return the builder
      */
-    public ExpressionClause<SetOutHeaderType> expression() {
+    public ExpressionClause<SetOutHeaderDefinition> expression() {
         return ExpressionClause.createAndSetExpression(this);
     }
 }
--- camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java (original)
+++ camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteContainer.java Fri Mar  6 08:20:00 2009
@@ -21,7 +21,7 @@
 import javax.xml.bind.annotation.XmlElementRef;
 
 /**
  * Container to hold {@link org.apache.camel.model.RouteType Route}.
  *
  * @version $Revision$
  */
@@ -33,12 +33,12 @@
      * @return the routes
      */
     @XmlElementRef
-    List<RouteType> getRoutes();
+    List<RouteDefinition> getRoutes();
 
     /**
      * Sets the routes to use
      *
      * @param routes the routes
      */
-    void setRoutes(List<RouteType> routes);
+    void setRoutes(List<RouteDefinition> routes);
 }
@@ -21,7 +21,7 @@
 
 /**
- * Container to hold {@link org.apache.camel.model.RouteType Route}.
+ * Container to hold {@link org.apache.camel.model.RouteDefinition Route}.
  *
  * @version $Revision$

Copied: camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteDefinition.java (from r750590, camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteType.java)
URL: http://svn.apache.org/viewvc/camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteDefinition.java?p2=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteDefinition.java&p1=camel/trunk/camel-core/src/main/java/org/apache/camel/model/RouteType.java&r1=750590&r2=750806&rev=750806&view=diff
==============================================================================